#!/bin/sh
# Copyright 2017 Lars Wirzenius
#
# This program is free software: you can redistribute it and/or modify
# it under the terms of the GNU Affero General Public License as published by
# the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU Affero General Public License for more details.
#
# You should have received a copy of the GNU Affero General Public License
# along with this program.  If not, see <http://www.gnu.org/licenses/>.

set -eu

export DISPLAY=

output="$(dirname "$1")/$(basename "$1" .mdwn)"

tmp="$(mktemp -d)"

clean()
{
    rm -rf "$tmp"
}

trap clean EXIT

cat -- "$@" | ./build.py "$tmp" > "$tmp/foo.mdwn"
pandoc --toc \
       -V documentclass:report \
       -Vgeometry:a4paper \
       -Vfontsize:12pt \
       -Vmainfont:FreeSerif \
       -Vsansfont:FreeSans \
       -Vmonofont:FreeMonoBold \
       -Vgeometry:"top=2cm, bottom=2.5cm, left=2cm, right=1cm" \
       --chapters \
       -o "$output.pdf" "$tmp/foo.mdwn"
pandoc --toc -o "$output.html" --number-sections --self-contained -H qvisqve.css "$tmp/foo.mdwn"
