# Copyright (C) 2017  Lars Wirzenius
#
# This program is free software: you can redistribute it and/or modify
# it under the terms of the GNU Affero General Public License as
# published by the Free Software Foundation, either version 3 of the
# License, or (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU Affero General Public License for more details.
#
# You should have received a copy of the GNU Affero General Public License
# along with this program.  If not, see <http://www.gnu.org/licenses/>.


import qvisqve


class API:

    def __init__(self, config):
        self._config = config

    def find_missing_route(self, path):
        qvisqve.log.log('info', msg_text='find_missing_route', path=path)

        routers = [
            qvisqve.VersionRouter(),
            qvisqve.TokenRouter(
                self._create_token_generator(), self._get_clients()),
        ]

        routes = []
        for router in routers:
            routes.extend(router.get_routes())

        return routes

    def _create_token_generator(self):
        tg = qvisqve.TokenGenerator()
        cfg = self._config
        tg.set_issuer(cfg['token-issuer'])
        tg.set_lifetime(cfg['token-lifetime'])
        tg.set_signing_key(cfg['token-private-key'])
        return tg

    def _get_clients(self):
        return self._config.get('clients', {})
